"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ClusterProvider(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_ARN_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key_arn: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key_arn: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_arn", b"key_arn", "resource_info", b"resource_info"]) -> None: ...

global___ClusterProvider = ClusterProvider

@typing_extensions.final
class ClusterEncryptionConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    RESOURCES_FIELD_NUMBER: builtins.int
    PROVIDER_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def resources(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def provider(self) -> global___ClusterProvider: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        resources: collections.abc.Iterable[builtins.str] | None = ...,
        provider: global___ClusterProvider | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["provider", b"provider", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["provider", b"provider", "resource_info", b"resource_info", "resources", b"resources"]) -> None: ...

global___ClusterEncryptionConfig = ClusterEncryptionConfig

@typing_extensions.final
class ClusterResourcesVpcConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    PUBLIC_ACCESS_CIDRS_FIELD_NUMBER: builtins.int
    ENDPOINT_PRIVATE_ACCESS_FIELD_NUMBER: builtins.int
    ENDPOINT_PUBLIC_ACCESS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def public_access_cidrs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    endpoint_private_access: builtins.bool
    endpoint_public_access: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
        public_access_cidrs: collections.abc.Iterable[builtins.str] | None = ...,
        endpoint_private_access: builtins.bool = ...,
        endpoint_public_access: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["endpoint_private_access", b"endpoint_private_access", "endpoint_public_access", b"endpoint_public_access", "public_access_cidrs", b"public_access_cidrs", "resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "subnet_ids", b"subnet_ids"]) -> None: ...

global___ClusterResourcesVpcConfig = ClusterResourcesVpcConfig

@typing_extensions.final
class ClusterKubernetesNetworkConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SERVICE_IPV4_CIDR_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    service_ipv4_cidr: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        service_ipv4_cidr: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "service_ipv4_cidr", b"service_ipv4_cidr"]) -> None: ...

global___ClusterKubernetesNetworkConfig = ClusterKubernetesNetworkConfig

@typing_extensions.final
class Cluster(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ENCRYPTION_CONFIG_FIELD_NUMBER: builtins.int
    ROLE_ARN_FIELD_NUMBER: builtins.int
    RESOURCES_VPC_CONFIG_FIELD_NUMBER: builtins.int
    KUBERNETES_NETWORK_CONFIG_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    @property
    def encryption_config(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ClusterEncryptionConfig]: ...
    role_arn: builtins.str
    @property
    def resources_vpc_config(self) -> global___ClusterResourcesVpcConfig: ...
    @property
    def kubernetes_network_config(self) -> global___ClusterKubernetesNetworkConfig: ...
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        encryption_config: collections.abc.Iterable[global___ClusterEncryptionConfig] | None = ...,
        role_arn: builtins.str = ...,
        resources_vpc_config: global___ClusterResourcesVpcConfig | None = ...,
        kubernetes_network_config: global___ClusterKubernetesNetworkConfig | None = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kubernetes_network_config", b"kubernetes_network_config", "resource_info", b"resource_info", "resources_vpc_config", b"resources_vpc_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption_config", b"encryption_config", "kubernetes_network_config", b"kubernetes_network_config", "name", b"name", "resource_info", b"resource_info", "resources_vpc_config", b"resources_vpc_config", "role_arn", b"role_arn", "version", b"version"]) -> None: ...

global___Cluster = Cluster

@typing_extensions.final
class EKS(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CLUSTER_FIELD_NUMBER: builtins.int
    FARGATE_PROFILE_FIELD_NUMBER: builtins.int
    NODEGROUP_FIELD_NUMBER: builtins.int
    @property
    def cluster(self) -> global___Cluster: ...
    @property
    def fargate_profile(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FargateProfile]: ...
    @property
    def nodegroup(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Nodegroup]: ...
    def __init__(
        self,
        *,
        cluster: global___Cluster | None = ...,
        fargate_profile: collections.abc.Iterable[global___FargateProfile] | None = ...,
        nodegroup: collections.abc.Iterable[global___Nodegroup] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["cluster", b"cluster"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster", b"cluster", "fargate_profile", b"fargate_profile", "nodegroup", b"nodegroup"]) -> None: ...

global___EKS = EKS

@typing_extensions.final
class FargateProfileLabel(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    KEY_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    key: builtins.str
    value: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        key: builtins.str = ...,
        value: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "resource_info", b"resource_info", "value", b"value"]) -> None: ...

global___FargateProfileLabel = FargateProfileLabel

@typing_extensions.final
class FargateProfileSelector(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAMESPACE_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    namespace: builtins.str
    @property
    def labels(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FargateProfileLabel]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        namespace: builtins.str = ...,
        labels: collections.abc.Iterable[global___FargateProfileLabel] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["labels", b"labels", "namespace", b"namespace", "resource_info", b"resource_info"]) -> None: ...

global___FargateProfileSelector = FargateProfileSelector

@typing_extensions.final
class FargateProfile(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CLUSTER_NAME_FIELD_NUMBER: builtins.int
    FARGATE_PROFILE_NAME_FIELD_NUMBER: builtins.int
    POD_EXECUTION_ROLE_ARN_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    SELECTORS_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cluster_name: builtins.str
    fargate_profile_name: builtins.str
    pod_execution_role_arn: builtins.str
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def selectors(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___FargateProfileSelector]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cluster_name: builtins.str = ...,
        fargate_profile_name: builtins.str = ...,
        pod_execution_role_arn: builtins.str = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
        selectors: collections.abc.Iterable[global___FargateProfileSelector] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cluster_name", b"cluster_name", "fargate_profile_name", b"fargate_profile_name", "pod_execution_role_arn", b"pod_execution_role_arn", "resource_info", b"resource_info", "selectors", b"selectors", "subnets", b"subnets", "tags", b"tags"]) -> None: ...

global___FargateProfile = FargateProfile

@typing_extensions.final
class NodegroupScalingConfig(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    MIN_SIZE_FIELD_NUMBER: builtins.int
    DESIRED_SIZE_FIELD_NUMBER: builtins.int
    MAX_SIZE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    min_size: builtins.float
    desired_size: builtins.float
    max_size: builtins.float
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        min_size: builtins.float = ...,
        desired_size: builtins.float = ...,
        max_size: builtins.float = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["desired_size", b"desired_size", "max_size", b"max_size", "min_size", b"min_size", "resource_info", b"resource_info"]) -> None: ...

global___NodegroupScalingConfig = NodegroupScalingConfig

@typing_extensions.final
class NodegroupLaunchTemplateSpecification(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    version: builtins.str
    id: builtins.str
    name: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        version: builtins.str = ...,
        id: builtins.str = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["id", b"id", "name", b"name", "resource_info", b"resource_info", "version", b"version"]) -> None: ...

global___NodegroupLaunchTemplateSpecification = NodegroupLaunchTemplateSpecification

@typing_extensions.final
class NodegroupRemoteAccess(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SOURCE_SECURITY_GROUPS_FIELD_NUMBER: builtins.int
    EC2_SSH_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def source_security_groups(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    ec2_ssh_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        source_security_groups: collections.abc.Iterable[builtins.str] | None = ...,
        ec2_ssh_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ec2_ssh_key", b"ec2_ssh_key", "resource_info", b"resource_info", "source_security_groups", b"source_security_groups"]) -> None: ...

global___NodegroupRemoteAccess = NodegroupRemoteAccess

@typing_extensions.final
class Nodegroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class LabelsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    SCALING_CONFIG_FIELD_NUMBER: builtins.int
    LABELS_FIELD_NUMBER: builtins.int
    RELEASE_VERSION_FIELD_NUMBER: builtins.int
    NODEGROUP_NAME_FIELD_NUMBER: builtins.int
    SUBNETS_FIELD_NUMBER: builtins.int
    NODE_ROLE_FIELD_NUMBER: builtins.int
    AMI_TYPE_FIELD_NUMBER: builtins.int
    FORCE_UPDATE_ENABLED_FIELD_NUMBER: builtins.int
    VERSION_FIELD_NUMBER: builtins.int
    LAUNCH_TEMPLATE_FIELD_NUMBER: builtins.int
    REMOTE_ACCESS_FIELD_NUMBER: builtins.int
    DISK_SIZE_FIELD_NUMBER: builtins.int
    CLUSTER_NAME_FIELD_NUMBER: builtins.int
    INSTANCE_TYPES_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    @property
    def scaling_config(self) -> global___NodegroupScalingConfig: ...
    @property
    def labels(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    release_version: builtins.str
    nodegroup_name: builtins.str
    @property
    def subnets(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    node_role: builtins.str
    ami_type: builtins.str
    force_update_enabled: builtins.bool
    version: builtins.str
    @property
    def launch_template(self) -> global___NodegroupLaunchTemplateSpecification: ...
    @property
    def remote_access(self) -> global___NodegroupRemoteAccess: ...
    disk_size: builtins.float
    cluster_name: builtins.str
    @property
    def instance_types(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        scaling_config: global___NodegroupScalingConfig | None = ...,
        labels: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        release_version: builtins.str = ...,
        nodegroup_name: builtins.str = ...,
        subnets: collections.abc.Iterable[builtins.str] | None = ...,
        node_role: builtins.str = ...,
        ami_type: builtins.str = ...,
        force_update_enabled: builtins.bool = ...,
        version: builtins.str = ...,
        launch_template: global___NodegroupLaunchTemplateSpecification | None = ...,
        remote_access: global___NodegroupRemoteAccess | None = ...,
        disk_size: builtins.float = ...,
        cluster_name: builtins.str = ...,
        instance_types: collections.abc.Iterable[builtins.str] | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["launch_template", b"launch_template", "remote_access", b"remote_access", "resource_info", b"resource_info", "scaling_config", b"scaling_config"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["ami_type", b"ami_type", "cluster_name", b"cluster_name", "disk_size", b"disk_size", "force_update_enabled", b"force_update_enabled", "instance_types", b"instance_types", "labels", b"labels", "launch_template", b"launch_template", "node_role", b"node_role", "nodegroup_name", b"nodegroup_name", "release_version", b"release_version", "remote_access", b"remote_access", "resource_info", b"resource_info", "scaling_config", b"scaling_config", "subnets", b"subnets", "tags", b"tags", "version", b"version"]) -> None: ...

global___Nodegroup = Nodegroup



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ReplicationGroupNodeGroupConfiguration(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NODE_GROUP_ID_FIELD_NUMBER: builtins.int
    PRIMARY_AVAILABILITY_ZONE_FIELD_NUMBER: builtins.int
    REPLICA_AVAILABILITY_ZONES_FIELD_NUMBER: builtins.int
    REPLICA_COUNT_FIELD_NUMBER: builtins.int
    SLOTS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    node_group_id: builtins.str
    primary_availability_zone: builtins.str
    @property
    def replica_availability_zones(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    replica_count: builtins.int
    slots: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        node_group_id: builtins.str = ...,
        primary_availability_zone: builtins.str = ...,
        replica_availability_zones: collections.abc.Iterable[builtins.str] | None = ...,
        replica_count: builtins.int = ...,
        slots: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["node_group_id", b"node_group_id", "primary_availability_zone", b"primary_availability_zone", "replica_availability_zones", b"replica_availability_zones", "replica_count", b"replica_count", "resource_info", b"resource_info", "slots", b"slots"]) -> None: ...

global___ReplicationGroupNodeGroupConfiguration = ReplicationGroupNodeGroupConfiguration

@typing_extensions.final
class ReplicationGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    AT_REST_ENCRYPTION_ENABLED_FIELD_NUMBER: builtins.int
    AUTH_TOKEN_FIELD_NUMBER: builtins.int
    AUTO_MINOR_VERSION_UPGRADE_FIELD_NUMBER: builtins.int
    AUTOMATIC_FAILOVER_ENABLED_FIELD_NUMBER: builtins.int
    CACHE_NODE_TYPE_FIELD_NUMBER: builtins.int
    CACHE_PARAMETER_GROUP_NAME_FIELD_NUMBER: builtins.int
    CACHE_SECURITY_GROUP_NAMES_FIELD_NUMBER: builtins.int
    CACHE_SUBNET_GROUP_NAME_FIELD_NUMBER: builtins.int
    ENGINE_FIELD_NUMBER: builtins.int
    ENGINE_VERSION_FIELD_NUMBER: builtins.int
    KMS_KEY_ID_FIELD_NUMBER: builtins.int
    MULTI_AZ_ENABLED_FIELD_NUMBER: builtins.int
    NODE_GROUP_CONFIGURATION_FIELD_NUMBER: builtins.int
    NOTIFICATION_TOPIC_ARN_FIELD_NUMBER: builtins.int
    NUM_CACHE_CLUSTERS_FIELD_NUMBER: builtins.int
    NUM_NODE_GROUPS_FIELD_NUMBER: builtins.int
    PORT_FIELD_NUMBER: builtins.int
    PREFERRED_CACHE_CLUSTER_AZS_FIELD_NUMBER: builtins.int
    PREFERRED_MAINTENANCE_WINDOW_FIELD_NUMBER: builtins.int
    PRIMARY_CLUSTER_ID_FIELD_NUMBER: builtins.int
    REPLICAS_PER_NODE_GROUP_FIELD_NUMBER: builtins.int
    REPLICATION_GROUP_DESCRIPTION_FIELD_NUMBER: builtins.int
    REPLICATION_GROUP_ID_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_IDS_FIELD_NUMBER: builtins.int
    SNAPSHOT_ARNS_FIELD_NUMBER: builtins.int
    SNAPSHOT_NAME_FIELD_NUMBER: builtins.int
    SNAPSHOT_RETENTION_LIMIT_FIELD_NUMBER: builtins.int
    SNAPSHOT_WINDOW_FIELD_NUMBER: builtins.int
    SNAPSHOTTING_CLUSTER_ID_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    TRANSIT_ENCRYPTION_ENABLED_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    at_rest_encryption_enabled: builtins.bool
    auth_token: builtins.str
    auto_minor_version_upgrade: builtins.bool
    automatic_failover_enabled: builtins.bool
    cache_node_type: builtins.str
    cache_parameter_group_name: builtins.str
    @property
    def cache_security_group_names(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    cache_subnet_group_name: builtins.str
    engine: builtins.str
    engine_version: builtins.str
    kms_key_id: builtins.str
    multi_az_enabled: builtins.bool
    @property
    def node_group_configuration(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ReplicationGroupNodeGroupConfiguration]: ...
    notification_topic_arn: builtins.str
    num_cache_clusters: builtins.int
    num_node_groups: builtins.int
    port: builtins.int
    @property
    def preferred_cache_cluster_azs(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    preferred_maintenance_window: builtins.str
    primary_cluster_id: builtins.str
    replicas_per_node_group: builtins.int
    replication_group_description: builtins.str
    replication_group_id: builtins.str
    @property
    def security_group_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def snapshot_arns(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    snapshot_name: builtins.str
    snapshot_retention_limit: builtins.int
    snapshot_window: builtins.str
    snapshotting_cluster_id: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    transit_encryption_enabled: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        at_rest_encryption_enabled: builtins.bool = ...,
        auth_token: builtins.str = ...,
        auto_minor_version_upgrade: builtins.bool = ...,
        automatic_failover_enabled: builtins.bool = ...,
        cache_node_type: builtins.str = ...,
        cache_parameter_group_name: builtins.str = ...,
        cache_security_group_names: collections.abc.Iterable[builtins.str] | None = ...,
        cache_subnet_group_name: builtins.str = ...,
        engine: builtins.str = ...,
        engine_version: builtins.str = ...,
        kms_key_id: builtins.str = ...,
        multi_az_enabled: builtins.bool = ...,
        node_group_configuration: collections.abc.Iterable[global___ReplicationGroupNodeGroupConfiguration] | None = ...,
        notification_topic_arn: builtins.str = ...,
        num_cache_clusters: builtins.int = ...,
        num_node_groups: builtins.int = ...,
        port: builtins.int = ...,
        preferred_cache_cluster_azs: collections.abc.Iterable[builtins.str] | None = ...,
        preferred_maintenance_window: builtins.str = ...,
        primary_cluster_id: builtins.str = ...,
        replicas_per_node_group: builtins.int = ...,
        replication_group_description: builtins.str = ...,
        replication_group_id: builtins.str = ...,
        security_group_ids: collections.abc.Iterable[builtins.str] | None = ...,
        snapshot_arns: collections.abc.Iterable[builtins.str] | None = ...,
        snapshot_name: builtins.str = ...,
        snapshot_retention_limit: builtins.int = ...,
        snapshot_window: builtins.str = ...,
        snapshotting_cluster_id: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        transit_encryption_enabled: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["at_rest_encryption_enabled", b"at_rest_encryption_enabled", "auth_token", b"auth_token", "auto_minor_version_upgrade", b"auto_minor_version_upgrade", "automatic_failover_enabled", b"automatic_failover_enabled", "cache_node_type", b"cache_node_type", "cache_parameter_group_name", b"cache_parameter_group_name", "cache_security_group_names", b"cache_security_group_names", "cache_subnet_group_name", b"cache_subnet_group_name", "engine", b"engine", "engine_version", b"engine_version", "kms_key_id", b"kms_key_id", "multi_az_enabled", b"multi_az_enabled", "node_group_configuration", b"node_group_configuration", "notification_topic_arn", b"notification_topic_arn", "num_cache_clusters", b"num_cache_clusters", "num_node_groups", b"num_node_groups", "port", b"port", "preferred_cache_cluster_azs", b"preferred_cache_cluster_azs", "preferred_maintenance_window", b"preferred_maintenance_window", "primary_cluster_id", b"primary_cluster_id", "replicas_per_node_group", b"replicas_per_node_group", "replication_group_description", b"replication_group_description", "replication_group_id", b"replication_group_id", "resource_info", b"resource_info", "security_group_ids", b"security_group_ids", "snapshot_arns", b"snapshot_arns", "snapshot_name", b"snapshot_name", "snapshot_retention_limit", b"snapshot_retention_limit", "snapshot_window", b"snapshot_window", "snapshotting_cluster_id", b"snapshotting_cluster_id", "tags", b"tags", "transit_encryption_enabled", b"transit_encryption_enabled"]) -> None: ...

global___ReplicationGroup = ReplicationGroup

@typing_extensions.final
class ElastiCache_ReplicationGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    REPLICATION_GROUP_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_FIELD_NUMBER: builtins.int
    SECURITY_GROUP_INGRESS_FIELD_NUMBER: builtins.int
    SUBNET_GROUP_FIELD_NUMBER: builtins.int
    @property
    def replication_group(self) -> global___ReplicationGroup: ...
    @property
    def security_group(self) -> global___SecurityGroup: ...
    @property
    def security_group_ingress(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___SecurityGroupIngress]: ...
    @property
    def subnet_group(self) -> global___SubnetGroup: ...
    def __init__(
        self,
        *,
        replication_group: global___ReplicationGroup | None = ...,
        security_group: global___SecurityGroup | None = ...,
        security_group_ingress: collections.abc.Iterable[global___SecurityGroupIngress] | None = ...,
        subnet_group: global___SubnetGroup | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["replication_group", b"replication_group", "security_group", b"security_group", "subnet_group", b"subnet_group"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["replication_group", b"replication_group", "security_group", b"security_group", "security_group_ingress", b"security_group_ingress", "subnet_group", b"subnet_group"]) -> None: ...

global___ElastiCache_ReplicationGroup = ElastiCache_ReplicationGroup

@typing_extensions.final
class SecurityGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    description: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        description: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["description", b"description", "resource_info", b"resource_info"]) -> None: ...

global___SecurityGroup = SecurityGroup

@typing_extensions.final
class SecurityGroupIngress(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHE_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_NAME_FIELD_NUMBER: builtins.int
    E_C2_SECURITY_GROUP_OWNER_ID_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cache_security_group_name: builtins.str
    e_c2_security_group_name: builtins.str
    e_c2_security_group_owner_id: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cache_security_group_name: builtins.str = ...,
        e_c2_security_group_name: builtins.str = ...,
        e_c2_security_group_owner_id: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_security_group_name", b"cache_security_group_name", "e_c2_security_group_name", b"e_c2_security_group_name", "e_c2_security_group_owner_id", b"e_c2_security_group_owner_id", "resource_info", b"resource_info"]) -> None: ...

global___SecurityGroupIngress = SecurityGroupIngress

@typing_extensions.final
class SubnetGroup(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    CACHE_SUBNET_GROUP_NAME_FIELD_NUMBER: builtins.int
    DESCRIPTION_FIELD_NUMBER: builtins.int
    SUBNET_IDS_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    cache_subnet_group_name: builtins.str
    description: builtins.str
    @property
    def subnet_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        cache_subnet_group_name: builtins.str = ...,
        description: builtins.str = ...,
        subnet_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["cache_subnet_group_name", b"cache_subnet_group_name", "description", b"description", "resource_info", b"resource_info", "subnet_ids", b"subnet_ids"]) -> None: ...

global___SubnetGroup = SubnetGroup



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: azure/azure_microsoft_healthcareapis.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*azure/azure_microsoft_healthcareapis.proto\x12*oak9.tython.azure.microsoft_healthcareapis\x1a\x13shared/shared.proto\"b\n\x18Microsoft_HealthcareApis\x12\x46\n\x08services\x18\x01 \x01(\x0b\x32\x34.oak9.tython.azure.microsoft_healthcareapis.Services\"\xab\x03\n$WorkspacesPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12U\n\x10private_endpoint\x18\x03 \x01(\x0b\x32;.oak9.tython.azure.microsoft_healthcareapis.PrivateEndpoint\x12|\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32M.oak9.tython.azure.microsoft_healthcareapis.PrivateLinkServiceConnectionState\x12\x1a\n\x12provisioning_state\x18\x05 \x01(\t\x12K\n\x0bsystem_data\x18\x06 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_healthcareapis.SystemData\"\x9e\x03\n\'WorkspacesIotconnectorsFhirdestinations\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12V\n\x0c\x66hir_mapping\x18\x05 \x01(\x0b\x32@.oak9.tython.azure.microsoft_healthcareapis.IotMappingProperties\x12 \n\x18\x66hir_service_resource_id\x18\x06 \x01(\t\x12\x1a\n\x12provisioning_state\x18\x07 \x01(\t\x12)\n!resource_identity_resolution_type\x18\x08 \x01(\t\x12K\n\x0bsystem_data\x18\t \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_healthcareapis.SystemData\"\xa7\x06\n\x17WorkspacesIotconnectors\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x08identity\x18\x02 \x01(\x0b\x32J.oak9.tython.azure.microsoft_healthcareapis.ServiceManagedIdentityIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12X\n\x0e\x64\x65vice_mapping\x18\x05 \x01(\x0b\x32@.oak9.tython.azure.microsoft_healthcareapis.IotMappingProperties\x12\x7f\n ingestion_endpoint_configuration\x18\x06 \x01(\x0b\x32U.oak9.tython.azure.microsoft_healthcareapis.IotEventHubIngestionEndpointConfiguration\x12\x1a\n\x12provisioning_state\x18\x07 \x01(\t\x12K\n\x0bsystem_data\x18\x08 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_healthcareapis.SystemData\x12[\n\x04tags\x18\t \x03(\x0b\x32M.oak9.tython.azure.microsoft_healthcareapis.WorkspacesIotconnectors.TagsEntry\x12\x86\x01\n)workspaces_iotconnectors_fhirdestinations\x18\n \x03(\x0b\x32S.oak9.tython.azure.microsoft_healthcareapis.WorkspacesIotconnectorsFhirdestinations\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n)IotEventHubIngestionEndpointConfiguration\x12\x16\n\x0e\x63onsumer_group\x18\x01 \x01(\t\x12\x16\n\x0e\x65vent_hub_name\x18\x02 \x01(\t\x12+\n#fully_qualified_event_hub_namespace\x18\x03 \x01(\t\"\xa6\x01\n\x14IotMappingProperties\x12^\n\x07\x63ontent\x18\x01 \x03(\x0b\x32M.oak9.tython.azure.microsoft_healthcareapis.IotMappingProperties.ContentEntry\x1a.\n\x0c\x43ontentEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x93\t\n\x16WorkspacesFhirservices\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x08identity\x18\x02 \x01(\x0b\x32J.oak9.tython.azure.microsoft_healthcareapis.ServiceManagedIdentityIdentity\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x61\n\x0f\x61\x63\x63\x65ss_policies\x18\x06 \x03(\x0b\x32H.oak9.tython.azure.microsoft_healthcareapis.FhirServiceAccessPolicyEntry\x12\x62\n\x11\x61\x63r_configuration\x18\x07 \x01(\x0b\x32G.oak9.tython.azure.microsoft_healthcareapis.FhirServiceAcrConfiguration\x12x\n\x1c\x61uthentication_configuration\x18\x08 \x01(\x0b\x32R.oak9.tython.azure.microsoft_healthcareapis.FhirServiceAuthenticationConfiguration\x12\x64\n\x12\x63ors_configuration\x18\t \x01(\x0b\x32H.oak9.tython.azure.microsoft_healthcareapis.FhirServiceCorsConfiguration\x12\x13\n\x0b\x65vent_state\x18\n \x01(\t\x12h\n\x14\x65xport_configuration\x18\x0b \x01(\x0b\x32J.oak9.tython.azure.microsoft_healthcareapis.FhirServiceExportConfiguration\x12\x1a\n\x12provisioning_state\x18\x0c \x01(\t\x12\x1d\n\x15public_network_access\x18\r \x01(\t\x12}\n%resource_version_policy_configuration\x18\x0e \x01(\x0b\x32N.oak9.tython.azure.microsoft_healthcareapis.ResourceVersionPolicyConfiguration\x12K\n\x0bsystem_data\x18\x0f \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_healthcareapis.SystemData\x12Z\n\x04tags\x18\x10 \x03(\x0b\x32L.oak9.tython.azure.microsoft_healthcareapis.WorkspacesFhirservices.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x02\n\"ResourceVersionPolicyConfiguration\x12\x0f\n\x07\x64\x65\x66\x61ult\x18\x01 \x01(\t\x12\x8a\x01\n\x17resource_type_overrides\x18\x02 \x03(\x0b\x32i.oak9.tython.azure.microsoft_healthcareapis.ResourceVersionPolicyConfiguration.ResourceTypeOverridesEntry\x1a<\n\x1aResourceTypeOverridesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\">\n\x1e\x46hirServiceExportConfiguration\x12\x1c\n\x14storage_account_name\x18\x01 \x01(\t\"}\n\x1c\x46hirServiceCorsConfiguration\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x0f\n\x07headers\x18\x02 \x03(\t\x12\x0f\n\x07max_age\x18\x03 \x01(\x05\x12\x0f\n\x07methods\x18\x04 \x03(\t\x12\x0f\n\x07origins\x18\x05 \x03(\t\"j\n&FhirServiceAuthenticationConfiguration\x12\x10\n\x08\x61udience\x18\x01 \x01(\t\x12\x11\n\tauthority\x18\x02 \x01(\t\x12\x1b\n\x13smart_proxy_enabled\x18\x03 \x01(\x08\"\x90\x01\n\x1b\x46hirServiceAcrConfiguration\x12\x15\n\rlogin_servers\x18\x01 \x03(\t\x12Z\n\roci_artifacts\x18\x02 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_healthcareapis.ServiceOciArtifactEntry\"1\n\x1c\x46hirServiceAccessPolicyEntry\x12\x11\n\tobject_id\x18\x01 \x01(\t\"\xdd\x04\n\x17WorkspacesDicomservices\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\\\n\x08identity\x18\x02 \x01(\x0b\x32J.oak9.tython.azure.microsoft_healthcareapis.ServiceManagedIdentityIdentity\x12\x10\n\x08location\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12y\n\x1c\x61uthentication_configuration\x18\x05 \x01(\x0b\x32S.oak9.tython.azure.microsoft_healthcareapis.DicomServiceAuthenticationConfiguration\x12\x1a\n\x12provisioning_state\x18\x06 \x01(\t\x12\x1d\n\x15public_network_access\x18\x07 \x01(\t\x12K\n\x0bsystem_data\x18\x08 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_healthcareapis.SystemData\x12[\n\x04tags\x18\t \x03(\x0b\x32M.oak9.tython.azure.microsoft_healthcareapis.WorkspacesDicomservices.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\'DicomServiceAuthenticationConfiguration\x12\x0c\n\x04name\x18\x01 \x01(\t\"\xf8\x01\n\x1eServiceManagedIdentityIdentity\x12\x0c\n\x04type\x18\x01 \x01(\t\x12\x88\x01\n\x18user_assigned_identities\x18\x02 \x03(\x0b\x32\x66.oak9.tython.azure.microsoft_healthcareapis.ServiceManagedIdentityIdentity.UserAssignedIdentitiesEntry\x1a=\n\x1bUserAssignedIdentitiesEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x06\n\nWorkspaces\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08location\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x1a\n\x12provisioning_state\x18\x04 \x01(\t\x12\x1d\n\x15public_network_access\x18\x05 \x01(\t\x12K\n\x0bsystem_data\x18\x06 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_healthcareapis.SystemData\x12N\n\x04tags\x18\x07 \x03(\x0b\x32@.oak9.tython.azure.microsoft_healthcareapis.Workspaces.TagsEntry\x12\x65\n\x18workspaces_dicomservices\x18\x08 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_healthcareapis.WorkspacesDicomservices\x12\x65\n\x18workspaces_iotconnectors\x18\t \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_healthcareapis.WorkspacesIotconnectors\x12\x63\n\x17workspaces_fhirservices\x18\n \x03(\x0b\x32\x42.oak9.tython.azure.microsoft_healthcareapis.WorkspacesFhirservices\x12\x81\x01\n\'workspaces_private_endpoint_connections\x18\x0b \x03(\x0b\x32P.oak9.tython.azure.microsoft_healthcareapis.WorkspacesPrivateEndpointConnections\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xdc\x02\n\"ServicesPrivateEndpointConnections\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12U\n\x10private_endpoint\x18\x03 \x01(\x0b\x32;.oak9.tython.azure.microsoft_healthcareapis.PrivateEndpoint\x12|\n%private_link_service_connection_state\x18\x04 \x01(\x0b\x32M.oak9.tython.azure.microsoft_healthcareapis.PrivateLinkServiceConnectionState\x12\x1a\n\x12provisioning_state\x18\x05 \x01(\t\"\xc3\t\n\x08Services\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x65tag\x18\x02 \x01(\t\x12V\n\x08identity\x18\x03 \x01(\x0b\x32\x44.oak9.tython.azure.microsoft_healthcareapis.ServicesResourceIdentity\x12\x0c\n\x04kind\x18\x04 \x01(\t\x12\x10\n\x08location\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12]\n\x0f\x61\x63\x63\x65ss_policies\x18\x07 \x03(\x0b\x32\x44.oak9.tython.azure.microsoft_healthcareapis.ServiceAccessPolicyEntry\x12\x62\n\x11\x61\x63r_configuration\x18\x08 \x01(\x0b\x32G.oak9.tython.azure.microsoft_healthcareapis.ServiceAcrConfigurationInfo\x12x\n\x1c\x61uthentication_configuration\x18\t \x01(\x0b\x32R.oak9.tython.azure.microsoft_healthcareapis.ServiceAuthenticationConfigurationInfo\x12\x64\n\x12\x63ors_configuration\x18\n \x01(\x0b\x32H.oak9.tython.azure.microsoft_healthcareapis.ServiceCorsConfigurationInfo\x12m\n\x17\x63osmos_db_configuration\x18\x0b \x01(\x0b\x32L.oak9.tython.azure.microsoft_healthcareapis.ServiceCosmosDbConfigurationInfo\x12h\n\x14\x65xport_configuration\x18\x0c \x01(\x0b\x32J.oak9.tython.azure.microsoft_healthcareapis.ServiceExportConfigurationInfo\x12k\n\x1cprivate_endpoint_connections\x18\r \x03(\x0b\x32\x45.oak9.tython.azure.microsoft_healthcareapis.PrivateEndpointConnection\x12\x1a\n\x12provisioning_state\x18\x0e \x01(\t\x12\x1d\n\x15public_network_access\x18\x0f \x01(\t\x12K\n\x0bsystem_data\x18\x10 \x01(\x0b\x32\x36.oak9.tython.azure.microsoft_healthcareapis.SystemData\x12L\n\x04tags\x18\x11 \x03(\x0b\x32>.oak9.tython.azure.microsoft_healthcareapis.Services.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa0\x01\n\nSystemData\x12\x12\n\ncreated_at\x18\x01 \x01(\t\x12\x12\n\ncreated_by\x18\x02 \x01(\t\x12\x17\n\x0f\x63reated_by_type\x18\x03 \x01(\t\x12\x18\n\x10last_modified_at\x18\x04 \x01(\t\x12\x18\n\x10last_modified_by\x18\x05 \x01(\t\x12\x1d\n\x15last_modified_by_type\x18\x06 \x01(\t\"\x8c\x02\n\x19PrivateEndpointConnection\x12U\n\x10private_endpoint\x18\x01 \x01(\x0b\x32;.oak9.tython.azure.microsoft_healthcareapis.PrivateEndpoint\x12|\n%private_link_service_connection_state\x18\x02 \x01(\x0b\x32M.oak9.tython.azure.microsoft_healthcareapis.PrivateLinkServiceConnectionState\x12\x1a\n\x12provisioning_state\x18\x03 \x01(\t\"b\n!PrivateLinkServiceConnectionState\x12\x18\n\x10\x61\x63tions_required\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06status\x18\x03 \x01(\t\"\x1f\n\x0fPrivateEndpoint\x12\x0c\n\x04name\x18\x01 \x01(\t\">\n\x1eServiceExportConfigurationInfo\x12\x1c\n\x14storage_account_name\x18\x01 \x01(\t\"W\n ServiceCosmosDbConfigurationInfo\x12\x19\n\x11key_vault_key_uri\x18\x01 \x01(\t\x12\x18\n\x10offer_throughput\x18\x02 \x01(\x05\"}\n\x1cServiceCorsConfigurationInfo\x12\x19\n\x11\x61llow_credentials\x18\x01 \x01(\x08\x12\x0f\n\x07headers\x18\x02 \x03(\t\x12\x0f\n\x07max_age\x18\x03 \x01(\x05\x12\x0f\n\x07methods\x18\x04 \x03(\t\x12\x0f\n\x07origins\x18\x05 \x03(\t\"j\n&ServiceAuthenticationConfigurationInfo\x12\x10\n\x08\x61udience\x18\x01 \x01(\t\x12\x11\n\tauthority\x18\x02 \x01(\t\x12\x1b\n\x13smart_proxy_enabled\x18\x03 \x01(\x08\"\x90\x01\n\x1bServiceAcrConfigurationInfo\x12\x15\n\rlogin_servers\x18\x01 \x03(\t\x12Z\n\roci_artifacts\x18\x02 \x03(\x0b\x32\x43.oak9.tython.azure.microsoft_healthcareapis.ServiceOciArtifactEntry\"S\n\x17ServiceOciArtifactEntry\x12\x0e\n\x06\x64igest\x18\x01 \x01(\t\x12\x12\n\nimage_name\x18\x02 \x01(\t\x12\x14\n\x0clogin_server\x18\x03 \x01(\t\"-\n\x18ServiceAccessPolicyEntry\x12\x11\n\tobject_id\x18\x01 \x01(\t\"(\n\x18ServicesResourceIdentity\x12\x0c\n\x04type\x18\x01 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'azure.azure_microsoft_healthcareapis_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WORKSPACESIOTCONNECTORS_TAGSENTRY._options = None
  _WORKSPACESIOTCONNECTORS_TAGSENTRY._serialized_options = b'8\001'
  _IOTMAPPINGPROPERTIES_CONTENTENTRY._options = None
  _IOTMAPPINGPROPERTIES_CONTENTENTRY._serialized_options = b'8\001'
  _WORKSPACESFHIRSERVICES_TAGSENTRY._options = None
  _WORKSPACESFHIRSERVICES_TAGSENTRY._serialized_options = b'8\001'
  _RESOURCEVERSIONPOLICYCONFIGURATION_RESOURCETYPEOVERRIDESENTRY._options = None
  _RESOURCEVERSIONPOLICYCONFIGURATION_RESOURCETYPEOVERRIDESENTRY._serialized_options = b'8\001'
  _WORKSPACESDICOMSERVICES_TAGSENTRY._options = None
  _WORKSPACESDICOMSERVICES_TAGSENTRY._serialized_options = b'8\001'
  _SERVICEMANAGEDIDENTITYIDENTITY_USERASSIGNEDIDENTITIESENTRY._options = None
  _SERVICEMANAGEDIDENTITYIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_options = b'8\001'
  _WORKSPACES_TAGSENTRY._options = None
  _WORKSPACES_TAGSENTRY._serialized_options = b'8\001'
  _SERVICES_TAGSENTRY._options = None
  _SERVICES_TAGSENTRY._serialized_options = b'8\001'
  _MICROSOFT_HEALTHCAREAPIS._serialized_start=111
  _MICROSOFT_HEALTHCAREAPIS._serialized_end=209
  _WORKSPACESPRIVATEENDPOINTCONNECTIONS._serialized_start=212
  _WORKSPACESPRIVATEENDPOINTCONNECTIONS._serialized_end=639
  _WORKSPACESIOTCONNECTORSFHIRDESTINATIONS._serialized_start=642
  _WORKSPACESIOTCONNECTORSFHIRDESTINATIONS._serialized_end=1056
  _WORKSPACESIOTCONNECTORS._serialized_start=1059
  _WORKSPACESIOTCONNECTORS._serialized_end=1866
  _WORKSPACESIOTCONNECTORS_TAGSENTRY._serialized_start=1823
  _WORKSPACESIOTCONNECTORS_TAGSENTRY._serialized_end=1866
  _IOTEVENTHUBINGESTIONENDPOINTCONFIGURATION._serialized_start=1869
  _IOTEVENTHUBINGESTIONENDPOINTCONFIGURATION._serialized_end=2005
  _IOTMAPPINGPROPERTIES._serialized_start=2008
  _IOTMAPPINGPROPERTIES._serialized_end=2174
  _IOTMAPPINGPROPERTIES_CONTENTENTRY._serialized_start=2128
  _IOTMAPPINGPROPERTIES_CONTENTENTRY._serialized_end=2174
  _WORKSPACESFHIRSERVICES._serialized_start=2177
  _WORKSPACESFHIRSERVICES._serialized_end=3348
  _WORKSPACESFHIRSERVICES_TAGSENTRY._serialized_start=1823
  _WORKSPACESFHIRSERVICES_TAGSENTRY._serialized_end=1866
  _RESOURCEVERSIONPOLICYCONFIGURATION._serialized_start=3351
  _RESOURCEVERSIONPOLICYCONFIGURATION._serialized_end=3607
  _RESOURCEVERSIONPOLICYCONFIGURATION_RESOURCETYPEOVERRIDESENTRY._serialized_start=3547
  _RESOURCEVERSIONPOLICYCONFIGURATION_RESOURCETYPEOVERRIDESENTRY._serialized_end=3607
  _FHIRSERVICEEXPORTCONFIGURATION._serialized_start=3609
  _FHIRSERVICEEXPORTCONFIGURATION._serialized_end=3671
  _FHIRSERVICECORSCONFIGURATION._serialized_start=3673
  _FHIRSERVICECORSCONFIGURATION._serialized_end=3798
  _FHIRSERVICEAUTHENTICATIONCONFIGURATION._serialized_start=3800
  _FHIRSERVICEAUTHENTICATIONCONFIGURATION._serialized_end=3906
  _FHIRSERVICEACRCONFIGURATION._serialized_start=3909
  _FHIRSERVICEACRCONFIGURATION._serialized_end=4053
  _FHIRSERVICEACCESSPOLICYENTRY._serialized_start=4055
  _FHIRSERVICEACCESSPOLICYENTRY._serialized_end=4104
  _WORKSPACESDICOMSERVICES._serialized_start=4107
  _WORKSPACESDICOMSERVICES._serialized_end=4712
  _WORKSPACESDICOMSERVICES_TAGSENTRY._serialized_start=1823
  _WORKSPACESDICOMSERVICES_TAGSENTRY._serialized_end=1866
  _DICOMSERVICEAUTHENTICATIONCONFIGURATION._serialized_start=4714
  _DICOMSERVICEAUTHENTICATIONCONFIGURATION._serialized_end=4769
  _SERVICEMANAGEDIDENTITYIDENTITY._serialized_start=4772
  _SERVICEMANAGEDIDENTITYIDENTITY._serialized_end=5020
  _SERVICEMANAGEDIDENTITYIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_start=4959
  _SERVICEMANAGEDIDENTITYIDENTITY_USERASSIGNEDIDENTITIESENTRY._serialized_end=5020
  _WORKSPACES._serialized_start=5023
  _WORKSPACES._serialized_end=5824
  _WORKSPACES_TAGSENTRY._serialized_start=1823
  _WORKSPACES_TAGSENTRY._serialized_end=1866
  _SERVICESPRIVATEENDPOINTCONNECTIONS._serialized_start=5827
  _SERVICESPRIVATEENDPOINTCONNECTIONS._serialized_end=6175
  _SERVICES._serialized_start=6178
  _SERVICES._serialized_end=7397
  _SERVICES_TAGSENTRY._serialized_start=1823
  _SERVICES_TAGSENTRY._serialized_end=1866
  _SYSTEMDATA._serialized_start=7400
  _SYSTEMDATA._serialized_end=7560
  _PRIVATEENDPOINTCONNECTION._serialized_start=7563
  _PRIVATEENDPOINTCONNECTION._serialized_end=7831
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_start=7833
  _PRIVATELINKSERVICECONNECTIONSTATE._serialized_end=7931
  _PRIVATEENDPOINT._serialized_start=7933
  _PRIVATEENDPOINT._serialized_end=7964
  _SERVICEEXPORTCONFIGURATIONINFO._serialized_start=7966
  _SERVICEEXPORTCONFIGURATIONINFO._serialized_end=8028
  _SERVICECOSMOSDBCONFIGURATIONINFO._serialized_start=8030
  _SERVICECOSMOSDBCONFIGURATIONINFO._serialized_end=8117
  _SERVICECORSCONFIGURATIONINFO._serialized_start=8119
  _SERVICECORSCONFIGURATIONINFO._serialized_end=8244
  _SERVICEAUTHENTICATIONCONFIGURATIONINFO._serialized_start=8246
  _SERVICEAUTHENTICATIONCONFIGURATIONINFO._serialized_end=8352
  _SERVICEACRCONFIGURATIONINFO._serialized_start=8355
  _SERVICEACRCONFIGURATIONINFO._serialized_end=8499
  _SERVICEOCIARTIFACTENTRY._serialized_start=8501
  _SERVICEOCIARTIFACTENTRY._serialized_end=8584
  _SERVICEACCESSPOLICYENTRY._serialized_start=8586
  _SERVICEACCESSPOLICYENTRY._serialized_end=8631
  _SERVICESRESOURCEIDENTITY._serialized_start=8633
  _SERVICESRESOURCEIDENTITY._serialized_end=8673
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_scc.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11gcp/gcp_scc.proto\x12\x13oak9.tython.gcp.scc\x1a\x13shared/shared.proto\"7\n%SccNotificationConfigXStreamingConfig\x12\x0e\n\x06\x66ilter\x18\x01 \x01(\t\"P\n\x1eSccNotificationConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xf4\x02\n\x15SccNotificationConfig\x12\x11\n\tconfig_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0corganization\x18\x05 \x01(\t\x12\x14\n\x0cpubsub_topic\x18\x06 \x01(\t\x12\x17\n\x0fservice_account\x18\x07 \x01(\t\x12T\n\x10streaming_config\x18\x08 \x01(\x0b\x32:.oak9.tython.gcp.scc.SccNotificationConfigXStreamingConfig\x12\x45\n\x08timeouts\x18\t \x01(\x0b\x32\x33.oak9.tython.gcp.scc.SccNotificationConfigXTimeouts\x12\x37\n\rresource_info\x18\n \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"D\n\x12SccSourceXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xda\x01\n\tSccSource\x12\x13\n\x0b\x64\x65scription\x18\x01 \x01(\t\x12\x14\n\x0c\x64isplay_name\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x14\n\x0corganization\x18\x05 \x01(\t\x12\x39\n\x08timeouts\x18\x06 \x01(\x0b\x32\'.oak9.tython.gcp.scc.SccSourceXTimeouts\x12\x37\n\rresource_info\x18\x07 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_scc_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SCCNOTIFICATIONCONFIGXSTREAMINGCONFIG._serialized_start=63
  _SCCNOTIFICATIONCONFIGXSTREAMINGCONFIG._serialized_end=118
  _SCCNOTIFICATIONCONFIGXTIMEOUTS._serialized_start=120
  _SCCNOTIFICATIONCONFIGXTIMEOUTS._serialized_end=200
  _SCCNOTIFICATIONCONFIG._serialized_start=203
  _SCCNOTIFICATIONCONFIG._serialized_end=575
  _SCCSOURCEXTIMEOUTS._serialized_start=577
  _SCCSOURCEXTIMEOUTS._serialized_end=645
  _SCCSOURCE._serialized_start=648
  _SCCSOURCE._serialized_end=866
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_document.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x16gcp/gcp_document.proto\x12\x18oak9.tython.gcp.document\x1a\x13shared/shared.proto\">\n\x1c\x44ocumentAiProcessorXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\x8f\x02\n\x13\x44ocumentAiProcessor\x12\x14\n\x0c\x64isplay_name\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x14\n\x0ckms_key_name\x18\x03 \x01(\t\x12\x10\n\x08location\x18\x04 \x01(\t\x12\x0c\n\x04name\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04type\x18\x07 \x01(\t\x12H\n\x08timeouts\x18\x08 \x01(\x0b\x32\x36.oak9.tython.gcp.document.DocumentAiProcessorXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"L\n*DocumentAiProcessorDefaultVersionXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xe4\x01\n!DocumentAiProcessorDefaultVersion\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\tprocessor\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12V\n\x08timeouts\x18\x04 \x01(\x0b\x32\x44.oak9.tython.gcp.document.DocumentAiProcessorDefaultVersionXTimeouts\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_document_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DOCUMENTAIPROCESSORXTIMEOUTS._serialized_start=73
  _DOCUMENTAIPROCESSORXTIMEOUTS._serialized_end=135
  _DOCUMENTAIPROCESSOR._serialized_start=138
  _DOCUMENTAIPROCESSOR._serialized_end=409
  _DOCUMENTAIPROCESSORDEFAULTVERSIONXTIMEOUTS._serialized_start=411
  _DOCUMENTAIPROCESSORDEFAULTVERSIONXTIMEOUTS._serialized_end=487
  _DOCUMENTAIPROCESSORDEFAULTVERSION._serialized_start=490
  _DOCUMENTAIPROCESSORDEFAULTVERSION._serialized_end=718
# @@protoc_insertion_point(module_scope)



import uuid
from models.shared.shared_pb2 import Blueprint as BP
from models.shared.shared_pb2 import ValidationMetaInfo
from models.shared.shared_pb2 import Graph, VertexType, Vertex
from models.shared.shared_pb2 import Context as Ctx
from core.sdk.resource_map import grpc_type_map
from dataclasses import dataclass, field
from enum import Enum, unique
from typing import List, Tuple, ClassVar, Callable, Dict, Union, Set, Any
from colorama import Fore, Style

from core.bp_metadata_utils.blueprint_meta_data import BlueprintMetaData

ValidationFunction = Callable[[any], any]


class OrderedEnum(Enum):

    def __ge__(self, other):
        if self.__class__ is other.__class__:
            return self.value >= other.value
        return NotImplemented

    def __gt__(self, other):
        if self.__class__ is other.__class__:
            return self.value > other.value
        return NotImplemented

    def __le__(self, other):
        if self.__class__ is other.__class__:
            return self.value <= other.value
        return NotImplemented

    def __lt__(self, other):
        if self.__class__ is other.__class__:
            return self.value < other.value
        return NotImplemented


class Csp(Enum):
    Aws = 1
    Azure = 2


class DataSensitivity(OrderedEnum):
    Sensitive = 2
    NonSensitive = 1


class BusinessImpact(OrderedEnum):
    High = 3
    Medium = 2
    Low = 1


class DeploymentModel(OrderedEnum):
    Private = 3
    Hybrid = 2
    Public = 1


@dataclass
class ResourceMetadata:
    resource_id: str
    resource_name: str
    resource_type: str


class Context:

    def __init__(self, context: Ctx = None):
        """
        Business context of the architecture being secured 
                  
        Args:
            context (context_pb2): The proto context object is passed in and converted into a python object
        """

        #  Default context
        if not context:
            self.business_impact: BusinessImpact = BusinessImpact.High
            self.data_sensitivity: DataSensitivity = DataSensitivity.Sensitive
            self.deployment_model: DeploymentModel = DeploymentModel.Public
            self.internal_access = True
            self.external_access = False
            self.remote_access = False
            self.wireless_access = False
            self.outbound_access = False
            self.workforce = True
            self.consumers = True
            self.business_partners = True
            self.physical = False
            self.open = False
            self.limited_sensitive_data = False
            self.broad_sensitive_data = True
            self.security_privileged = True
            self.component_core = True
            self.user_interface = True
            self.management_interface = True
            return

    def is_externally_accessible(self):
        if self.external_access and not self.internal_access:
            return True

        return False

    def is_data_sensitive(self):
        if self.data_sensitivity == DataSensitivity.Sensitive:
            return True
        return False

    def is_impact_high(self):

        if self.business_impact == BusinessImpact.High:
            return True

        return False

    def is_impact_moderate(self):

        if self.business_impact == BusinessImpact.Medium:
            return True

        return False

    def is_impact_low(self):

        if self.business_impact == BusinessImpact.Low:
            return True

        return False

    def is_business_critical(self):

        if self.business_impact == BusinessImpact.High and self.data_sensitivity == DataSensitivity.Sensitive:
            return True
        else:
            return False

    def is_impact_high_or_data_sensitive(self):

        if self.business_impact == BusinessImpact.High or self.data_sensitivity == DataSensitivity.Sensitive:
            return True
        else:
            return False

    def is_sensitive(self):
        if self.data_sensitivity == DataSensitivity.Sensitive:
            return True
        else:
            return False

    def is_sensitive_and_external(self):

        if self.data_sensitivity == DataSensitivity.Sensitive and self.external_access:
            return True
        else:
            return False

    def is_sensitive_and_internal(self):
        if self.data_sensitivity == DataSensitivity.Sensitive and self.internal_access:
            return True
        else:
            return False

    def determine_severity(self):

        if self.business_impact == BusinessImpact.High:
            config_violation_severity = Severity.High

        elif self.business_impact == BusinessImpact.Medium:
            config_violation_severity = Severity.Moderate

        else:
            config_violation_severity = Severity.Low

        return config_violation_severity


Default_Context = Context()


class BlueprintType(Enum):
    Component = 1
    Reference = 2
    Solution = 3
    Resource = 4
    Customer = 5


@dataclass
class Resource:
    id: str
    name: str
    csp: Csp
    resource_type: ClassVar[str]
    id: str
    name: str
    blueprint_id: str


class WellDoneRating(OrderedEnum):
    Amazing = 4
    Great = 3
    Good = 2
    Ok = 1


class Severity(OrderedEnum):
    Critical = 4
    High = 3
    Moderate = 2
    Low = 1


class RelatedConfig:
    """
    Related Configs allows the Violation to bundle additional configurations that don't need a separate violation
    and should be remediated together
    """
    config_id: str = ""
    config_value: Union[List, int, str] = ""
    preferred_value: Union[List, int, str] = ""
    comment: str = ""


class Violation:
    """
    Defines a violation object.
    This object is DEPRECATED and is only there for backwards compatibility
    Note that there are required and optional fields
    """

    def __init__(
            self,
            severity: Severity = Severity.Low,
            adjusted_severity: Severity = None,
            config_id: str = "",
            config_value: str = "",
            config_gap: str = "",
            config_impact: str = "",
            config_fix: str = "",
            preferred_value: Union[List, str, int] = "",
            additional_guidance: str = "",
            documentation: str = "",
            related_configs: List[RelatedConfig] = None,
            capability_id: str = "",
            capability_name: str = "",
            resource_id: str = "",
            resource_type: str = "",
            resource_name: str = "",
            priority: int = 0
    ):

        # Severity of the violation.  Default to low. Severity should be determined based on the business context
        self._severity = severity

        # Adjusted severity of the violation. This field is used to adjust the severity for a mitigating design
        self._adjusted_severity = adjusted_severity

        # the unique id (full path) of the configuration that has the issue
        self.config_id = config_id

        # currently configured value of this configuration
        if type(config_value) != str:
            self.config_value = str(config_value)

        else:
            self.config_value = config_value

        # Description of the gap 
        self.config_gap = config_gap

        # Impact of not fixing this violation
        self.config_impact = config_impact

        # Guidance on how to fix the issue
        self.config_fix = config_fix

        # The preferred value
        # Preferred values can be strings, integers, bools, lists, dictionaries
        if type(preferred_value) == list:
            self.preferred_value = ', '.join(preferred_value)

        elif type(preferred_value) != str:
            self.preferred_value = str(preferred_value)

        else:
            self.preferred_value = preferred_value

        # Additional guidance 
        self.additional_guidance = additional_guidance

        # Related configurations that should be remediated together 
        self.related_configs: List[RelatedConfig] = related_configs

        # oak9 security capability requirement id
        self._capability_id = capability_id

        # oak9 detailed requirement name
        self._capability_name = capability_name

        # documentation link
        self._documentation = documentation

        # Unique id of the resource
        self._resource_id = resource_id

        # Type of resource
        self._resource_type = resource_type

        # resource name
        self._resource_name = resource_name

        # Priority of finding (1-100)
        # This helps relatively prioritize across qualitative ratings
        self._priority = priority

    def __json__(self):
        return {
            'severity': self.severity.name,
            'configGap': self.config_gap,
            'capabilityId': self.capability_id,
            'configId': self.config_id,
            'configValue': self.config_value,
            'oak9Guidance': self.additional_guidance,
            'prefferedValue': self.preferred_value,
            'capabilityName': self.capability_name,
            'configFix': self.config_fix,
            'configImpact': self.config_impact,
            'resourceId': self.resource_id,
            'resourceType': self.resource_type,
            'resourceName': self.resource_name
        }

    @property
    def severity(self) -> Severity:
        return self._severity

    @severity.setter
    def severity(self, value):
        if self._adjusted_severity:
            self._severity = self._adjusted_severity
        else:
            self._severity = value

    @property
    def adjusted_severity(self):
        return self._adjusted_severity

    @adjusted_severity.setter
    def adjusted_severity(self, value):
        self._adjusted_severity = value

    @property
    def documentation(self):
        return self._documentation

    @property
    def capability_id(self):
        return self._capability_id

    @capability_id.setter
    def capability_id(self, value):
        self._capability_id = value

    @property
    def capability_name(self):
        return self._capability_name

    @capability_name.setter
    def capability_name(self, value):
        self._capability_name = value

    @property
    def priority(self):
        return self._priority

    @priority.setter
    def priority(self, value):
        if isinstance(value, int) and 101 > value > 0:
            self._priority = value

    @property
    def resource_id(self):
        return self._resource_id

    @resource_id.setter
    def resource_id(self, value):
        self._resource_id = value

    @property
    def resource_type(self):
        return self._resource_type

    @resource_type.setter
    def resource_type(self, value):
        self._resource_type = value

    @property
    def resource_name(self):
        return self._resource_name
    
    @resource_name.setter
    def resource_name(self, value):
        self._resource_name = value

@dataclass
class DesignGap:
    """
    Defines the design gap object, which is a collection of violations
    This object is DEPRECATED and is only there for backwards compatibility
    Note that there are required and optional fields
    """
    # What is the  gap
    capability_gap: str = ""

    # What is the impact
    capability_impact: str = ""

    # severity of the design gap
    _severity: Severity = Severity.Low

    # List of violations
    violations: List[Violation] = field(default_factory=list)

    def add_violation(self, violations: List[Violation]):
        self.violations.extend(violations)
        self._update_severity()

    def _update_severity(self):
        for viol in self.violations:
            if viol.severity > self._severity:
                self._severity = viol.severity


class FindingType(Enum):
    DesignGap = 1
    Kudos = 2
    Warning = 3
    Task = 4
    ResourceGap = 5


class Finding:
    """
    Defines a Finding object.
    """

    def __init__(
            self,
            resource: Any,
            resource_metadata: ResourceMetadata,
            finding_type: FindingType,
            desc: str,
            rating: Union[Severity, WellDoneRating] = Severity.Low,
            adjusted_severity: Severity = None,
            config_id: str = "",
            current_value: str = "",
            fix: str = "",
            preferred_value="",
            additional_guidance: str = "",
            related_configs: List[RelatedConfig] = None,
            related_findings: List[uuid.UUID] = None,
            req_id: str = "",
            req_name: str = "",
            priority: int = 0,
            documentation_url="",
            cost_consideration: bool = False,
            env: str = ""
    ):
        """
        Type of observation
        """

        self._id = uuid.uuid4()

        """
        Metadata of the resource that this finding relates to
        """
        self._resource: Any = resource

        self._resource_metadata: ResourceMetadata = resource_metadata

        """
        Findings can be of type Design Gap, Resource Gap, Kudos, Task or Warning
        """
        self._finding_type: FindingType = finding_type

        """
        For Design Gaps and Tasks: 
            Severity of the gap or task.  Default to low. 
            Severity should be determined based on the business context
            Resource blueprints can also specify adjusted severity. When an adjusted severity is specified, it does
            not allow the Component blueprint to set the severity for this violation.
        
        For Kudos: 
            Well done rating. Should be determined based on the business context
        
        For Warnings: N/A
        """
        self._rating = rating

        """
        Currently N/A to Tython
        This field is meant to provide an adjusted severity rating for mitigating designs
        """
        self._adjusted_severity = adjusted_severity

        """
        the unique id (full path) of the configuration that we want to call out
        e.g. LoadBalancer.listeners[0].listenerCertificates[2].certificate[1].name
        This field should be auto-populated using a utility function (get_config_id)
        """

        self._config_id = config_id

        # currently configured value of this configuration
        if type(current_value) != str:
            self._current_value = str(current_value)
        else:
            self._current_value = current_value

        """
        For design gaps - Description of the gap, framed neutrally as a recommendation.
            Guidance on language - This field should be framed in a neutral way (as opposed to a negative framing).
            This field should focus on explicitly defining "What is the recommendation" and implicitly defining "What is the gap"
            The Fix field will define the How do I fix it

            Examples:
            
                Instead of "Encryption is not configured" we focus on the recommendation "Enable Encryption"
            
                For lists: instead of "[configId] contains insecure origin values" say 
                "Remove origins from CORS rules that allow broad access"
            
                Instead of "SSL Protocol is not set to TLS.v1.2" we should say "SSL protocol should use latest protocol version"
                
                Instead of "Encryption is not enabled" we should say "Enable encryption"

        For Kudos - Description of the passed check
        
        For Tasks - Description of the task
        
        For Warnings - Description of the warnings
        """

        self._desc = desc

        # Specific details on the gap (for cases where the gap gets displayed separately)
        self._fix = fix

        # oak9's preferred value
        # preferred values can be strings, integers, bools, lists, dictionaries
        # the platform is responsible for checking type to use-cases like remediation
        # or displaying design gaps
        # (Required for remediation)
        if type(preferred_value) == list:
            self._preferred_value = ', '.join(preferred_value)

        elif type(preferred_value) != str:
            self._preferred_value = str(preferred_value)

        else:
            self._preferred_value = preferred_value

        # Additional guidance
        self._additional_guidance = additional_guidance

        # Related configurations that should be remediated together or
        # are better presented bundled together
        self._related_configs: List[RelatedConfig] = related_configs or []

        # add documentation link
        # Currently this is auto-populated on the platform side
        self._documentation_url = documentation_url

        # Requirement id
        # Could be oak9 or customer provided requirement id
        self._req_id = req_id

        # oak9 detailed requirement name
        # This is automatically populated on the platform side
        self._req_name = req_name

        # Priority of finding to relatively prioritize across
        # qualitative ratings.  Can be any number from 0-100
        self._priority = priority

        # Related findings
        # List of UUIDs for related findings
        self._related_findings = related_findings or []

        # Note if the finding will lead to higher costs for the customers if they follow our guidance
        self._cost_consideration = cost_consideration

        # environment as defined by customer
        self._env = env

    @property
    def id(self):
        return self._id

    @property
    def resource(self):
        return self._resource

    @property
    def resource_metadata(self):
        return self._resource_metadata

    @property
    def finding_type(self):
        return self._finding_type

    @finding_type.setter
    def finding_type(self, value):
        self._finding_type = value

    @property
    def rating(self):
        return self._rating

    @rating.setter
    def rating(self, value):
        self._rating = value

    @property
    def config_id(self):
        return self._config_id

    @config_id.setter
    def config_id(self, value):
        self._config_id = value

    @property
    def current_value(self):
        return self._current_value

    @current_value.setter
    def current_value(self, value):
        self._current_value = value

    @property
    def desc(self):
        return self._desc

    @desc.setter
    def desc(self, value):
        self._desc = value

    @property
    def fix(self):
        return self._fix

    @fix.setter
    def fix(self, value):
        self._fix = value

    @property
    def preferred_value(self):
        return self._preferred_value

    @preferred_value.setter
    def preferred_value(self, value):
        if type(value) == list:
            self._preferred_value = ', '.join(value)
        elif type(value) != str:
            self._preferred_value = str(value)
        else:
            self._preferred_value = value

    @property
    def additional_guidance(self):
        return self._additional_guidance

    @additional_guidance.setter
    def additional_guidance(self, value):
        self._additional_guidance = value

    @property
    def severity(self) -> Severity:
        return self._rating

    @severity.setter
    def severity(self, value):
        if self._adjusted_severity:
            self._rating = self._adjusted_severity
        else:
            self._rating = value

    @property
    def adjusted_severity(self):
        return self._adjusted_severity

    @adjusted_severity.setter
    def adjusted_severity(self, value):
        self._adjusted_severity = value

    @property
    def capability_id(self):
        return self._req_id

    @capability_id.setter
    def capability_id(self, value):
        self._req_id = value

    @property
    def capability_name(self):
        return self._req_name

    @capability_name.setter
    def capability_name(self, value):
        self._req_name = value

    @property
    def req_id(self):
        return self._req_id

    @req_id.setter
    def req_id(self, value):
        # TODO: add checks for user provided ids vs oak9 ids
        self._req_id = value

    @property
    def req_name(self):
        return self._req_name

    @req_name.setter
    def req_name(self, value):
        # TODO: add checks for user provided reqs vs oak9 reqs
        self._req_name = value

    @property
    def related_configs(self):
        return self._related_configs

    def add_related_config(self, related_config: RelatedConfig):
        self._related_configs.append(related_config)

    @property
    def priority(self) -> int:
        return self._priority

    @property
    def env(self) -> str:
        return self._env

    @env.setter
    def env(self, value: str):
        self._env = value

    @priority.setter
    def priority(self, value: int):
        if isinstance(value, int):
            if self.severity == Severity.Critical:
                self._priority = value if value > 75 else 75
            elif self.severity == Severity.High:
                self._priority = value if (50 < value < 74) else 74 if value > 50 else 50
            elif self.severity == Severity.Moderate:
                self._priority = value if (25 < value < 49) else 49 if value > 25 else 25
            elif self.severity == Severity.Low:
                self._priority = value if (0 < value < 24) else 24 if value > 0 else 0

    @property
    def related_findings(self):
        return self._related_findings

    @property
    def documentation_url(self):
        return self._documentation_url

    @documentation_url.setter
    def documentation_url(self, value):
        self._documentation_url = value

    @property
    def cost_consideration(self) -> bool:
        return self._cost_consideration

    @cost_consideration.setter
    def cost_consideration(self, value: bool):
        self._cost_consideration = value

    def add_related_findings(self, related_findings: Union[uuid.UUID, List]):
        if isinstance(related_findings, uuid.UUID):
            self._related_findings.append(related_findings)
        elif isinstance(related_findings, list):
            for finding in related_findings:
                if isinstance(related_findings, uuid.UUID):
                    self._related_findings.append(finding)

    @classmethod
    def from_violation(cls, viol: Violation):
        self = cls.__new__(cls)
        self._finding_type = FindingType.DesignGap
        self._desc = viol.config_gap
        self._rating = viol.severity
        self._adjusted_severity = viol.adjusted_severity
        self._config_id = viol.config_id
        self._current_value = viol.config_value
        self._desc = viol.config_fix
        self._preferred_value = viol.preferred_value
        self._additional_guidance = viol.additional_guidance
        self._documentation_url = viol.documentation
        self._related_configs = viol.related_configs or []
        self._req_id = viol.capability_id
        self._req_name = viol.capability_name
        self.priority = viol.priority
        return self

    def to_violation(self):
        viol = Violation()
        if self.finding_type not in [FindingType.DesignGap, FindingType.ResourceGap]:
            return None

        viol.config_gap = self.desc
        viol.severity = self.rating
        viol.adjusted_severity = self.adjusted_severity
        viol.config_id = self.config_id
        viol.config_value = self.current_value
        viol.config_fix = self.fix
        viol.preferred_value = self.preferred_value
        viol.additional_guidance = self.additional_guidance
        viol._documentation = self.documentation_url
        viol.related_configs = self.related_configs
        viol.capability_id = self.req_id
        viol.capability_name = self.req_name
        viol.priority = self.priority
        viol.resource_id = "" if not self.resource else self.resource.resource_info.id
        viol.resource_type = "" if not self.resource else self.resource.resource_info.resource_type
        viol.resource_name = "" if not self.resource else self.resource.resource_info.name
        
        return viol

    def __json__(self):
        return {
            "finding_type": self.finding_type.name,
            "desc": self.desc,
            "rating": self.rating.name,
            "adjusted_severity": "" if not self.adjusted_severity else self.adjusted_severity,
            "config_id": self.config_id,
            "current_value": self.current_value,
            "fix": self.fix,
            "preferred_value": self.preferred_value,
            "additional_guidance": self.additional_guidance,
            "related_configs": self.related_configs,
            "related_findings": self.related_findings,
            "req_id": self.req_id,
            "req_name": self.req_name,
            "priority": self.priority,
            "documentation_url": self.documentation_url
        }

    def __str__(self):
        ret_str = ''
        ret_str += f"Finding Type: {self.finding_type}\n"
        if self.finding_type in [FindingType.DesignGap, FindingType.ResourceGap, FindingType.Task]:
            ret_str += f"Severity: {self.severity}\n"
            ret_str += f"Action Required: {self.desc}\n"
            ret_str += f"Fix: {self.fix}\n" if self.fix else ''
        elif self.finding_type == FindingType.Kudos:
            ret_str += f"Rating: {self.rating}\n"
            ret_str += f"Description: {self.desc}\n"
        elif self.finding_type == Warning:
            ret_str += f"Description: {self.desc}\n"
        return ret_str


@dataclass
class ValidationMetaInfo:
    caller: str
    request_id: str
    resource_type: str
    blueprint_id: str
    resource_name: str
    resource_id: str


class DesignPref:
    pass


class Blueprint:
    """
    Base class for Tython Blueprints
    """
    display_name: ClassVar[str] = None
    blueprint_type: ClassVar[BlueprintType] = BlueprintType.Customer
    id: ClassVar[str] = None
    parent_blueprint_id: ClassVar[str] = None
    version: ClassVar[str] = None

    def __init__(self, graph: Graph, context: Context = None) -> None:
        self._graph = graph
        self._context = context
        self._meta_info = None

    @property
    def context(self):
        return self._context

    @property
    def meta_info(self):
        return self._meta_info

    @meta_info.setter
    def meta_info(self, value):
        pass

    @property
    def graph(self):
        return self._graph

    def validate(self) -> Set[Finding]:
        pass

    def find_by_resource(self, resource_type):
        """
        Filters the graph for the given resource_type
        """
        resources = []

        for input in self._graph:
            for root_node in input.graph.root_nodes:
                mapped = grpc_type_map.get(root_node.node.resource.data.type_url)
                if mapped == resource_type:
                    resource = resource_type()
                    root_node.node.resource.data.Unpack(resource)

                    resource_metadata = ResourceMetadata(
                        resource_id=input.meta_info.resource_id,
                        resource_name=input.meta_info.resource_name,
                        resource_type=input.meta_info.resource_type
                    )

                    resources.append((resource, resource_metadata))

        return resources


@dataclass
class Configuration:
    api_key: str = None
    org_id: str = None
    project_id: str = None
    blueprint_package_path: str = None
    data_endpoint: str = None
    mode: str = None

    def __init__(self, api_key: str, org_id: str, project_id: str, blueprint_package_path: str,
                 data_endpoint: str = None, mode: str = None, **kwargs):
        self.api_key = api_key
        self.org_id = org_id
        self.project_id = project_id
        self.blueprint_package_path = blueprint_package_path
        self.data_endpoint = "https://api.oak9.io/console/" if not data_endpoint else data_endpoint
        self.mode = "test" if not mode else mode
        for key, value in kwargs.items():
            setattr(self, key, value)


@dataclass
class RunnerReport:
    blueprint_metadata: List[BlueprintMetaData]
    blueprint_output: List[str]
    blueprint_problems: List[str]
    findings: List[Finding]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_network.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1dgcp/gcp_compute_network.proto\x12\x1foak9.tython.gcp.compute_network\x1a\x13shared/shared.proto\"I\n\x17\x43omputeNetworkXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xaa\x03\n\x0e\x43omputeNetwork\x12\x1f\n\x17\x61uto_create_subnetworks\x18\x01 \x01(\x08\x12\'\n\x1f\x64\x65lete_default_routes_on_create\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12 \n\x18\x65nable_ula_internal_ipv6\x18\x04 \x01(\x08\x12\x14\n\x0cgateway_ipv4\x18\x05 \x01(\t\x12\n\n\x02id\x18\x06 \x01(\t\x12\x1b\n\x13internal_ipv6_range\x18\x07 \x01(\t\x12\x0b\n\x03mtu\x18\x08 \x01(\x01\x12\x0c\n\x04name\x18\t \x01(\t\x12\x0f\n\x07project\x18\n \x01(\t\x12\x14\n\x0crouting_mode\x18\x0b \x01(\t\x12\x11\n\tself_link\x18\x0c \x01(\t\x12J\n\x08timeouts\x18\r \x01(\x0b\x32\x38.oak9.tython.gcp.compute_network.ComputeNetworkXTimeouts\x12\x37\n\rresource_info\x18\x0e \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"A\n\x1f\x43omputeNetworkEndpointXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xa4\x02\n\x16\x43omputeNetworkEndpoint\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08instance\x18\x02 \x01(\t\x12\x12\n\nip_address\x18\x03 \x01(\t\x12\x1e\n\x16network_endpoint_group\x18\x04 \x01(\t\x12\x0c\n\x04port\x18\x05 \x01(\x01\x12\x0f\n\x07project\x18\x06 \x01(\t\x12\x0c\n\x04zone\x18\x07 \x01(\t\x12R\n\x08timeouts\x18\x08 \x01(\x0b\x32@.oak9.tython.gcp.compute_network.ComputeNetworkEndpointXTimeouts\x12\x37\n\rresource_info\x18\t \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"F\n$ComputeNetworkEndpointGroupXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\"\xf8\x02\n\x1b\x43omputeNetworkEndpointGroup\x12\x14\n\x0c\x64\x65\x66\x61ult_port\x18\x01 \x01(\x01\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12\x0f\n\x07network\x18\x05 \x01(\t\x12\x1d\n\x15network_endpoint_type\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x11\n\tself_link\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x01\x12\x12\n\nsubnetwork\x18\n \x01(\t\x12\x0c\n\x04zone\x18\x0b \x01(\t\x12W\n\x08timeouts\x18\x0c \x01(\x0b\x32\x45.oak9.tython.gcp.compute_network.ComputeNetworkEndpointGroupXTimeouts\x12\x37\n\rresource_info\x18\r \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"P\n\x1e\x43omputeNetworkPeeringXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xa0\x03\n\x15\x43omputeNetworkPeering\x12\x1c\n\x14\x65xport_custom_routes\x18\x01 \x01(\x08\x12+\n#export_subnet_routes_with_public_ip\x18\x02 \x01(\x08\x12\n\n\x02id\x18\x03 \x01(\t\x12\x1c\n\x14import_custom_routes\x18\x04 \x01(\x08\x12+\n#import_subnet_routes_with_public_ip\x18\x05 \x01(\x08\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07network\x18\x07 \x01(\t\x12\x14\n\x0cpeer_network\x18\x08 \x01(\t\x12\r\n\x05state\x18\t \x01(\t\x12\x15\n\rstate_details\x18\n \x01(\t\x12Q\n\x08timeouts\x18\x0b \x01(\x0b\x32?.oak9.tython.gcp.compute_network.ComputeNetworkPeeringXTimeouts\x12\x37\n\rresource_info\x18\x0c \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\\\n*ComputeNetworkPeeringRoutesConfigXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\xb6\x02\n!ComputeNetworkPeeringRoutesConfig\x12\x1c\n\x14\x65xport_custom_routes\x18\x01 \x01(\x08\x12\n\n\x02id\x18\x02 \x01(\t\x12\x1c\n\x14import_custom_routes\x18\x03 \x01(\x08\x12\x0f\n\x07network\x18\x04 \x01(\t\x12\x0f\n\x07peering\x18\x05 \x01(\t\x12\x0f\n\x07project\x18\x06 \x01(\t\x12]\n\x08timeouts\x18\x07 \x01(\x0b\x32K.oak9.tython.gcp.compute_network.ComputeNetworkPeeringRoutesConfigXTimeouts\x12\x37\n\rresource_info\x18\x08 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_network_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTENETWORKXTIMEOUTS._serialized_start=87
  _COMPUTENETWORKXTIMEOUTS._serialized_end=160
  _COMPUTENETWORK._serialized_start=163
  _COMPUTENETWORK._serialized_end=589
  _COMPUTENETWORKENDPOINTXTIMEOUTS._serialized_start=591
  _COMPUTENETWORKENDPOINTXTIMEOUTS._serialized_end=656
  _COMPUTENETWORKENDPOINT._serialized_start=659
  _COMPUTENETWORKENDPOINT._serialized_end=951
  _COMPUTENETWORKENDPOINTGROUPXTIMEOUTS._serialized_start=953
  _COMPUTENETWORKENDPOINTGROUPXTIMEOUTS._serialized_end=1023
  _COMPUTENETWORKENDPOINTGROUP._serialized_start=1026
  _COMPUTENETWORKENDPOINTGROUP._serialized_end=1402
  _COMPUTENETWORKPEERINGXTIMEOUTS._serialized_start=1404
  _COMPUTENETWORKPEERINGXTIMEOUTS._serialized_end=1484
  _COMPUTENETWORKPEERING._serialized_start=1487
  _COMPUTENETWORKPEERING._serialized_end=1903
  _COMPUTENETWORKPEERINGROUTESCONFIGXTIMEOUTS._serialized_start=1905
  _COMPUTENETWORKPEERINGROUTESCONFIGXTIMEOUTS._serialized_end=1997
  _COMPUTENETWORKPEERINGROUTESCONFIG._serialized_start=2000
  _COMPUTENETWORKPEERINGROUTESCONFIG._serialized_end=2310
# @@protoc_insertion_point(module_scope)
